verify_deduction

Function verify_deduction 

pub fn verify_deduction<Atomic>(
    premises: impl IntoIterator<Item = Atomic>,
    inferences: impl IntoIterator<Item = SupportingInference<Atomic>>,
) -> Result<(), InvalidDeduction<Atomic>>
where Atomic: AtomicConstraint,
Verify that a deduction is valid given the inferences in the proof stage.

The inferences are considered in the order they are provided.