VariableState

Struct VariableState 

pub struct VariableState<Atomic: AtomicConstraint> { /* private fields */ }
The domains of all variables in the problem.

Domains are initially unbounded. This is why bounds are represented as IntExt.

Domains can be reduced through VariableState::apply. By default, the domain of every variable is infinite.

Implementations

Source

impl<Atomic> VariableState<Atomic>
where Atomic: AtomicConstraint,

pub fn prepare_for_conflict_check( premises: impl IntoIterator<Item = Atomic>, consequent: Option<Atomic>, ) -> Result<Self, Atomic::Identifier>

Create a variable state that applies all the premises and, if present, the negation of the consequent.

If premises /\ !consequent contain mutually exclusive atomic constraints (e.g., [x >= 5] and [x <= 2]) then None is returned.

An InferenceChecker will receive a VariableState that conforms to this description.

pub fn domains<'this>( &'this self, ) -> impl Iterator<Item = &'this Atomic::Identifier> + 'this
where Atomic::Identifier: 'this,

The domains for which at least one atomic is applied.

pub fn lower_bound(&self, identifier: &Atomic::Identifier) -> IntExt

Get the lower bound of a variable.

pub fn upper_bound(&self, identifier: &Atomic::Identifier) -> IntExt

Get the upper bound of a variable.

pub fn contains(&self, identifier: &Atomic::Identifier, value: i32) -> bool

Tests whether the given value is in the domain of the variable.

pub fn holes<'a>( &'a self, identifier: &Atomic::Identifier, ) -> impl Iterator<Item = i32> + 'a
where Atomic::Identifier: 'a,

Get the holes within the lower and upper bound of the variable expression.

pub fn fixed_value(&self, identifier: &Atomic::Identifier) -> Option<i32>

Get the fixed value of this variable, if it is fixed.

pub fn iter_domain<'a>( &'a self, identifier: &Atomic::Identifier, ) -> Option<DomainIterator<'a>>
where Atomic::Identifier: 'a,

Obtain an iterator over the domain of the variable.

If the domain is unbounded, then None is returned.

pub fn apply(&mut self, atomic: &Atomic) -> bool

Apply the given Atomic to the state.

Returns true if the state remains consistent, or false if the atomic cannot be true in conjunction with previously applied atomics.

pub fn is_true(&self, atomic: &Atomic) -> bool

Is the given atomic true in the current state.