pub trait InferenceChecker<Atomic: AtomicConstraint>: Debug + DynClone {
// Required method
fn check(
&self,
state: VariableState<Atomic>,
premises: &[Atomic],
consequent: Option<&Atomic>,
) -> bool;
}Expand description
An inference checker tests whether the given state is a conflict under the sematics of an inference rule.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".