pub struct IgnoredInference<Atomic> {
pub inference: SupportingInference<Atomic>,
pub unsatisfied_premises: Vec<Atomic>,
}Expand description
An inference that was ignored when checking a deduction.
Returned as an error when checking a deduction. These inferences were added to the proof stage, but never used. Hence, they likely point to why the proof stage is rejected.
Fields
inference: SupportingInference<Atomic>The inference that was ignored.
unsatisfied_premises: Vec<Atomic>The premises that were not satisfied when the inference was evaluated.