InferenceChecker

Trait InferenceChecker 

pub trait InferenceChecker<Atomic: AtomicConstraint>: Debug + DynClone {
    // Required method
    fn check(
        &self,
        state: VariableState<Atomic>,
        premises: &[Atomic],
        consequent: Option<&Atomic>,
    ) -> bool;
}
An inference checker tests whether the given state is a conflict under the sematics of an inference rule.

Required Methods

fn check( &self, state: VariableState<Atomic>, premises: &[Atomic], consequent: Option<&Atomic>, ) -> bool

Returns true if state is a conflict, and false if not.

For the conflict check, all the premises are true in the state and the consequent, if present, is false.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors