pub trait InferenceChecker<Atomic: AtomicConstraint>: Debug + DynClone {
// Required method
fn check(
&self,
state: VariableState<Atomic>,
premises: &[Atomic],
consequent: Option<&Atomic>,
) -> bool;
}Expand description
An inference checker tests whether the given state is a conflict under the sematics of an inference rule.